Learn R Programming

fitdistrplus (version 1.0-2)

bootdistcens: Bootstrap simulation of uncertainty for censored data

Description

Uses nonparametric bootstrap resampling in order to simulate uncertainty in the parameters of the distribution fitted to censored data.

Usage

bootdistcens(f, niter=1001)
## S3 method for class 'bootdistcens':
print(x, \dots)
## S3 method for class 'bootdistcens':
plot(x, \dots)
## S3 method for class 'bootdistcens':
summary(object, \dots)

Arguments

f
An object of class "fitdistcens", output of the fitdistcens function.
niter
The number of samples drawn by bootstrap.
x
An object of class "bootdistcens".
object
An object of class "bootdistcens".
...
Further arguments to be passed to generic methods

Value

  • bootdistcens returns an object of class "bootdistcens", a list with 6 components,
  • estima data frame containing the bootstrapped values of parameters.
  • converga vector containing the codes for convergence of the iterative method used to estimate parameters on each bootstraped data set.
  • methodA character string coding for the type of resampling : in this case "nonparam" as it is the only available method for censored data.
  • nbbootThe number of samples drawn by bootstrap.
  • CIbootstrap medians and 95 percent confidence percentile intervals of parameters.
  • fitpartThe object of class "fitdistcens" on which the bootstrap procedure was applied.
  • Generic functions: [object Object],[object Object],[object Object]

Details

Samples are drawn by nonparametric bootstrap (resampling with replacement from the data set). On each bootstrap sample the function mledist is used to estimate bootstrapped values of parameters. When mledist fails to converge, NA values are returned. Medians and 2.5 and 97.5 percentiles are computed by removing NA values. The medians and the 95 percent confidence intervals of parameters (2.5 and 97.5 percentiles) are printed in the summary. If inferior to the whole number of iterations, the number of iterations for which mledist converges is also printed in the summary. The plot of an object of class "bootdistcens" consists in a scatterplot or a matrix of scatterplots of the bootstrapped values of parameters. It uses the function stripchart when the fitted distribution is characterized by only one parameter, and the function plot in other cases. In these last cases, it provides a representation of the joint uncertainty distribution of the fitted parameters.

References

Cullen AC and Frey HC (1999) Probabilistic techniques in exposure assessment. Plenum Press, USA, pp. 181-241.

See Also

fitdistcens, mledist and quantile.bootdistcens for another generic function to calculate quantiles from the fitted distribution and its bootstrap results.

Examples

Run this code
# We choose a low number of bootstrap replicates in order to satisfy CRAN running times constraint.
# For practical applications, we recommend to use at least niter=501 or niter=1001.

# (1) Fit of a normal distribution to fluazinam data in log10
# followed by nonparametric bootstrap and calculation of quantiles
# with 95 percent confidence intervals
#
data(fluazinam)
(d1 <-log10(fluazinam))
f1 <- fitdistcens(d1, "norm")
b1 <- bootdistcens(f1, niter = 101)
b1
summary(b1)
plot(b1)
quantile(b1)

# (2) Estimation of the mean of the normal distribution 
# by maximum likelihood with the standard deviation fixed at 1 
# using the argument fix.arg
# followed by nonparametric bootstrap 
# and calculation of quantiles with 95 percent confidence intervals
#
f1b <- fitdistcens(d1, "norm", start = list(mean = 1),fix.arg = list(sd = 1))
b1b <- bootdistcens(f1b, niter = 101)
summary(b1b)
plot(b1b)
quantile(b1b)

Run the code above in your browser using DataLab